==> jc-1.4.0.tar.gz: java/util/zip/GZIPOutputStream.h <==
// public class java.util.zip.GZIPOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f80e6f4ae1ff7e14 java_util_zip_DeflaterOutputStream
// @dep_class 5a888c733ac5af5d java_util_zip_GZIPOutputStream

// header file dependencies
// @dep_header java_util_zip_DeflaterOutputStream

#include "java/util/zip/DeflaterOutputStream.h"

#ifndef _JC_java_util_zip_GZIPOutputStream_H_
#define _JC_java_util_zip_GZIPOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_CRC32$object;

// Typedefs
typedef struct _jc_java_util_zip_GZIPOutputStream$sub_refs	_jc_java_util_zip_GZIPOutputStream$sub_refs;
typedef struct _jc_java_util_zip_GZIPOutputStream$sub_nonrefs	_jc_java_util_zip_GZIPOutputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_GZIPOutputStream$refs	_jc_java_util_zip_GZIPOutputStream$refs;
typedef struct _jc_java_util_zip_GZIPOutputStream$nonrefs	_jc_java_util_zip_GZIPOutputStream$nonrefs;
typedef struct _jc_java_util_zip_GZIPOutputStream$object	_jc_java_util_zip_GZIPOutputStream$object;

typedef const struct _jc_java_util_zip_GZIPOutputStream$vmethods	_jc_java_util_zip_GZIPOutputStream$vmethods;
typedef const struct _jc_java_util_zip_GZIPOutputStream$vtable	_jc_java_util_zip_GZIPOutputStream$vtable;
typedef const struct _jc_java_util_zip_GZIPOutputStream$vtype	_jc_java_util_zip_GZIPOutputStream$vtype;

// Constructors
extern void _jc_java_util_zip_GZIPOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_java_util_zip_GZIPOutputStream$method$_init$782fe41f0aefd897(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *, struct _jc_java_io_OutputStream$object *, jint);

// Virtual methods
extern void _jc_java_util_zip_GZIPOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *);
extern void _jc_java_util_zip_GZIPOutputStream$method$finish$8d1c944274527186(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *);
extern void _jc_java_util_zip_GZIPOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_GZIPOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_zip_GZIPOutputStream$method_info$finish$8d1c944274527186;
extern _jc_method _jc_java_util_zip_GZIPOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_util_zip_GZIPOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *);
	void	(*finish$8d1c944274527186)(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_util_zip_GZIPOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_DeflaterOutputStream$vmethods	java_util_zip_DeflaterOutputStream;
	_jc_java_util_zip_GZIPOutputStream$vmethods	java_util_zip_GZIPOutputStream;
};

// Vtype
struct _jc_java_util_zip_GZIPOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_GZIPOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_GZIPOutputStream$sub_refs {
	struct _jc_java_util_zip_CRC32$object	*crc;
};

// Reference instance fields (object)
struct _jc_java_util_zip_GZIPOutputStream$refs {
    _jc_java_util_zip_GZIPOutputStream$sub_refs	java_util_zip_GZIPOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_refs	java_util_zip_DeflaterOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_GZIPOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_GZIPOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	java_util_zip_DeflaterOutputStream;
    _jc_java_util_zip_GZIPOutputStream$sub_nonrefs	java_util_zip_GZIPOutputStream;
};

// Object instance structure
struct _jc_java_util_zip_GZIPOutputStream$object {
	_jc_java_util_zip_GZIPOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_GZIPOutputStream$vtype	*vtype;
	_jc_java_util_zip_GZIPOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_GZIPOutputStream$vtype _jc_java_util_zip_GZIPOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_GZIPOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_GZIPOutputStream$class_object;

#endif	/* _JC_java_util_zip_GZIPOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/GZIPOutputStream.h <==
// public class java.util.zip.GZIPOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f80e6f4ae1ff7e14 java_util_zip_DeflaterOutputStream
// @dep_class 5a888c733ac5af5d java_util_zip_GZIPOutputStream

// header file dependencies
// @dep_header java_util_zip_DeflaterOutputStream

#include "java/util/zip/DeflaterOutputStream.h"

#ifndef _JC_java_util_zip_GZIPOutputStream_H_
#define _JC_java_util_zip_GZIPOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_CRC32$object;

// Typedefs
typedef struct _jc_java_util_zip_GZIPOutputStream$sub_refs	_jc_java_util_zip_GZIPOutputStream$sub_refs;
typedef struct _jc_java_util_zip_GZIPOutputStream$sub_nonrefs	_jc_java_util_zip_GZIPOutputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_GZIPOutputStream$refs	_jc_java_util_zip_GZIPOutputStream$refs;
typedef struct _jc_java_util_zip_GZIPOutputStream$nonrefs	_jc_java_util_zip_GZIPOutputStream$nonrefs;
typedef struct _jc_java_util_zip_GZIPOutputStream$object	_jc_java_util_zip_GZIPOutputStream$object;

typedef const struct _jc_java_util_zip_GZIPOutputStream$vmethods	_jc_java_util_zip_GZIPOutputStream$vmethods;
typedef const struct _jc_java_util_zip_GZIPOutputStream$vtable	_jc_java_util_zip_GZIPOutputStream$vtable;
typedef const struct _jc_java_util_zip_GZIPOutputStream$vtype	_jc_java_util_zip_GZIPOutputStream$vtype;

// Constructors
extern void _jc_java_util_zip_GZIPOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_GZIPOutputStream$method$_init$782fe41f0aefd897(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *, struct _jc_java_io_OutputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_zip_GZIPOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_GZIPOutputStream$method$finish$8d1c944274527186(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_GZIPOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_GZIPOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_zip_GZIPOutputStream$method_info$finish$8d1c944274527186;
extern _jc_method _jc_java_util_zip_GZIPOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_util_zip_GZIPOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *) _JC_JCNI_ATTR;
	void	(*finish$8d1c944274527186)(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_util_zip_GZIPOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_GZIPOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_DeflaterOutputStream$vmethods	java_util_zip_DeflaterOutputStream;
	_jc_java_util_zip_GZIPOutputStream$vmethods	java_util_zip_GZIPOutputStream;
};

// Vtype
struct _jc_java_util_zip_GZIPOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_GZIPOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_GZIPOutputStream$sub_refs {
	struct _jc_java_util_zip_CRC32$object	*crc;
};

// Reference instance fields (object)
struct _jc_java_util_zip_GZIPOutputStream$refs {
    _jc_java_util_zip_GZIPOutputStream$sub_refs	java_util_zip_GZIPOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_refs	java_util_zip_DeflaterOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_GZIPOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_GZIPOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	java_util_zip_DeflaterOutputStream;
    _jc_java_util_zip_GZIPOutputStream$sub_nonrefs	java_util_zip_GZIPOutputStream;
};

// Object instance structure
struct _jc_java_util_zip_GZIPOutputStream$object {
	_jc_java_util_zip_GZIPOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_GZIPOutputStream$vtype	*vtype;
	_jc_java_util_zip_GZIPOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_GZIPOutputStream$vtype _jc_java_util_zip_GZIPOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_GZIPOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_GZIPOutputStream$class_object;

#endif	/* _JC_java_util_zip_GZIPOutputStream_H_ */
